@@ -231,7 +231,7 @@ namespace kt
 			return false;
 
 		bt::TorrentFileInterface & file = tc->getTorrentFile(r);;
-		Priority prio = (bt::Priority)value.toInt();
+		auto prio = (bt::Priority)value.toInt();
 		Priority old = file.getPriority();
 
 		if (prio != old)
@@ -247,14 +247,14 @@ namespace kt
 	{
         Q_UNUSED(percentage)
 		QModelIndex idx = createIndex(file->getIndex(),4,file);
-		emit dataChanged(idx,idx);
+		Q_EMIT dataChanged(idx,idx);
 	}
 
 	void IWFileListModel::filePreviewChanged(bt::TorrentFileInterface* file,bool preview)
 	{
         Q_UNUSED(preview)
 		QModelIndex idx = createIndex(file->getIndex(),3,file);
-		emit dataChanged(idx,idx);
+		Q_EMIT dataChanged(idx,idx);
 	}
 
 	void IWFileListModel::update()
