@@ -289,7 +289,7 @@ void TransferKio::slotVerified(bool isVerified)
 
 void TransferKio::slotStatResult(KJob* kioJob)
 {
-    KIO::StatJob * statJob = qobject_cast<KIO::StatJob *>(kioJob);
+    auto * statJob = qobject_cast<KIO::StatJob *>(kioJob);
 
     if (!statJob->error()) {
         const KIO::UDSEntry entryResult = statJob->statResult();
